==> jc-1.4.0.tar.gz: jas/InterfaceCP.h <==
// public class jas.InterfaceCP

// class file dependencies
// @dep_class c0e5264359137f3 jas_CP
// @dep_class 2f024c7f78ef3e40 jas_InterfaceCP
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header jas_CP

#include "jas/CP.h"

#ifndef _JC_jas_InterfaceCP_H_
#define _JC_jas_InterfaceCP_H_

// Forward structure declarations
struct _jc_jas_ClassCP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_NameTypeCP$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_jas_InterfaceCP$sub_refs	_jc_jas_InterfaceCP$sub_refs;
typedef struct _jc_jas_InterfaceCP$sub_nonrefs	_jc_jas_InterfaceCP$sub_nonrefs;
typedef struct _jc_jas_InterfaceCP$refs	_jc_jas_InterfaceCP$refs;
typedef struct _jc_jas_InterfaceCP$nonrefs	_jc_jas_InterfaceCP$nonrefs;
typedef struct _jc_jas_InterfaceCP$object	_jc_jas_InterfaceCP$object;

typedef const struct _jc_jas_InterfaceCP$vmethods	_jc_jas_InterfaceCP$vmethods;
typedef const struct _jc_jas_InterfaceCP$vtable	_jc_jas_InterfaceCP$vtable;
typedef const struct _jc_jas_InterfaceCP$vtype	_jc_jas_InterfaceCP$vtype;

// Constructors
extern void _jc_jas_InterfaceCP$method$_init$ab068ddc672b930e(_jc_env *, struct _jc_jas_InterfaceCP$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_jas_InterfaceCP$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_InterfaceCP$object *, struct _jc_jas_ClassEnv$object *);
extern void _jc_jas_InterfaceCP$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_InterfaceCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_InterfaceCP$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_InterfaceCP$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_InterfaceCP$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_InterfaceCP$object *, struct _jc_jas_ClassEnv$object *);
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_InterfaceCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_InterfaceCP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_CP$vmethods	jas_CP;
	_jc_jas_InterfaceCP$vmethods	jas_InterfaceCP;
};

// Vtype
struct _jc_jas_InterfaceCP$vtype {
	_jc_type			type;
	_jc_jas_InterfaceCP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_InterfaceCP$sub_refs {
	struct _jc_jas_ClassCP$object	*clazz;
	struct _jc_jas_NameTypeCP$object	*nt;
};

// Reference instance fields (object)
struct _jc_jas_InterfaceCP$refs {
    _jc_jas_InterfaceCP$sub_refs	jas_InterfaceCP;
    _jc_jas_CP$sub_refs	jas_CP;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_InterfaceCP$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_InterfaceCP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_CP$sub_nonrefs	jas_CP;
    _jc_jas_InterfaceCP$sub_nonrefs	jas_InterfaceCP;
};

// Object instance structure
struct _jc_jas_InterfaceCP$object {
	_jc_jas_InterfaceCP$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_InterfaceCP$vtype	*vtype;
	_jc_jas_InterfaceCP$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_InterfaceCP$vtype _jc_jas_InterfaceCP$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_InterfaceCP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_InterfaceCP$class_object;

#endif	/* _JC_jas_InterfaceCP_H_ */

==> jc-1.4.6.tar.gz: jas/InterfaceCP.h <==
// public class jas.InterfaceCP

// class file dependencies
// @dep_class c0e5264359137f3 jas_CP
// @dep_class 2f024c7f78ef3e40 jas_InterfaceCP
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header jas_CP

#include "jas/CP.h"

#ifndef _JC_jas_InterfaceCP_H_
#define _JC_jas_InterfaceCP_H_

// Forward structure declarations
struct _jc_jas_ClassCP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_NameTypeCP$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_jas_InterfaceCP$sub_refs	_jc_jas_InterfaceCP$sub_refs;
typedef struct _jc_jas_InterfaceCP$sub_nonrefs	_jc_jas_InterfaceCP$sub_nonrefs;
typedef struct _jc_jas_InterfaceCP$refs	_jc_jas_InterfaceCP$refs;
typedef struct _jc_jas_InterfaceCP$nonrefs	_jc_jas_InterfaceCP$nonrefs;
typedef struct _jc_jas_InterfaceCP$object	_jc_jas_InterfaceCP$object;

typedef const struct _jc_jas_InterfaceCP$vmethods	_jc_jas_InterfaceCP$vmethods;
typedef const struct _jc_jas_InterfaceCP$vtable	_jc_jas_InterfaceCP$vtable;
typedef const struct _jc_jas_InterfaceCP$vtype	_jc_jas_InterfaceCP$vtype;

// Constructors
extern void _jc_jas_InterfaceCP$method$_init$ab068ddc672b930e(_jc_env *, struct _jc_jas_InterfaceCP$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_InterfaceCP$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_InterfaceCP$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern void _jc_jas_InterfaceCP$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_InterfaceCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_InterfaceCP$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_InterfaceCP$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_InterfaceCP$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_InterfaceCP$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_InterfaceCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_InterfaceCP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_CP$vmethods	jas_CP;
	_jc_jas_InterfaceCP$vmethods	jas_InterfaceCP;
};

// Vtype
struct _jc_jas_InterfaceCP$vtype {
	_jc_type			type;
	_jc_jas_InterfaceCP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_InterfaceCP$sub_refs {
	struct _jc_jas_ClassCP$object	*clazz;
	struct _jc_jas_NameTypeCP$object	*nt;
};

// Reference instance fields (object)
struct _jc_jas_InterfaceCP$refs {
    _jc_jas_InterfaceCP$sub_refs	jas_InterfaceCP;
    _jc_jas_CP$sub_refs	jas_CP;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_InterfaceCP$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_InterfaceCP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_CP$sub_nonrefs	jas_CP;
    _jc_jas_InterfaceCP$sub_nonrefs	jas_InterfaceCP;
};

// Object instance structure
struct _jc_jas_InterfaceCP$object {
	_jc_jas_InterfaceCP$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_InterfaceCP$vtype	*vtype;
	_jc_jas_InterfaceCP$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_InterfaceCP$vtype _jc_jas_InterfaceCP$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_InterfaceCP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_InterfaceCP$class_object;

#endif	/* _JC_jas_InterfaceCP_H_ */
